define(
//begin v1.x content
{
	"scientificFormat": "#E0",
	"infinity": "∞",
	"superscriptingExponent": "×",
	"list": ";",
	"percentSign": "%",
	"minusSign": "−",
	"decimalFormat-short": "000 bil'.'",
	"nan": "NaN",
	"currencyFormat": "#,##0.00 ¤;(#,##0.00 ¤)",
	"perMille": "‰",
	"group": ".",
	"percentFormat": "#,##0 %",
	"decimalFormat-long": "000 bilijonov",
	"decimalFormat": "#,##0.###",
	"currencyFormat-short": "000 bil'.' ¤",
	"timeSeparator": ":",
	"decimal": ",",
	"exponential": "e"
}
//end v1.x content
);